# SUS01-BP01: Choose region based on sustainability goals

## Description

Select regions với lower carbon intensity.

## Implementation Guidance

- Research region carbon intensity
- Prioritize regions with renewable energy
- Balance latency vs sustainability
- Track carbon footprint per region
- Document region selection rationale

## Risk Level

Low - Region choice impacts carbon footprint.

## Related Best Practices

- [SUS02-BP04](../SUS02-Alignment-Alignment-To-Demand/SUS02-BP04-Geographic-Placement.md)
- [PERF04-BP06](../../04-PERF/PERF04-Networking-Networking/PERF04-BP06-Location-Network-Requirements.md)
